@@ -32,7 +32,7 @@ getcoremetadatafromtsn <- function(tsn = NA,
   xpathfunc <- function(x) {    
     sapply(getNodeSet(out, paste("//ax23:", x, sep=''), namespaces=namespaces),xmlValue)
   }
-  df <-  do.call(cbind, laply(toget, as.data.frame(xpathfunc)))
+  df <-  do.call(cbind, lapply(toget, as.data.frame(xpathfunc)))
   names(df) <- toget
   df
 }
\ No newline at end of file
