@@ -1,6 +1,7 @@
 #' Returns the scientific name for the TSN. Also returns the component parts 
 #'    (names and indicators) of the scientific name.
-#' @import XML RCurl plyr
+#' 
+#' @import XML RCurl
 #' @param tsn TSN for a taxonomic group (numeric)
 #' @param url the ITIS API url for the function (should be left to default)
 #' @param ... optional additional curl options (debugging tools mostly)
@@ -30,7 +31,7 @@ getscientificnamefromtsn <- function(tsn = NA,
   xpathfunc <- function(x) {    
     sapply(getNodeSet(out, paste("//ax23:", x, sep=''), namespaces=namespaces),xmlValue)
   }
-  df <-  do.call(cbind, laply(toget, as.data.frame(xpathfunc)))
+  df <-  do.call(cbind, lapply(toget, as.data.frame(xpathfunc)))
   names(df) <- toget
   df
 }
\ No newline at end of file
